@@ -6,7 +6,7 @@ from django.contrib.admin.options import InlineModelAdmin
 from django.contrib.admin.utils import flatten_fieldsets
 from django.contrib.auth.admin import UserAdmin
 from django.db import models
-from django.db.models.fields.reverse_related import ForeignObjectRel
+from django.db.models.fields.reverse_related import ForeignObjectRel, OneToOneRel
 from django.forms.models import _get_foreign_key
 
 from .common import debug_log, settings
@@ -91,17 +91,19 @@ def _get_all_admin_fields(request):
         else:
             obj = None
 
-        try:
-            fields = admin.get_fieldsets(request, obj)
-        except Exception as e:  # pragma: no cover
-            debug_log(e)  # ignore things like HaystackResultsAdmin
-        else:
-            for f in flatten_fieldsets(fields):
-                # skip calculated fields on inlines
-                if not isinstance(admin, InlineModelAdmin) or hasattr(admin.model, f):
-                    yield f
+        fields = admin.get_fieldsets(request, obj)
+        for f in flatten_fieldsets(fields):
+            # skip calculated fields on inlines
+            if not isinstance(admin, InlineModelAdmin) or hasattr(admin.model, f):
+                yield f
 
     def visible(model_admin, request):
+        attrs = ["get_fieldsets", "model", "get_queryset"]
+        if not all(hasattr(model_admin, a) for a in attrs):
+            debug_log(
+                f"{type(model_admin)} instance does not look like a ModelAdmin or InlineModelAdmin"
+            )
+            return False
         if getattr(model_admin, "ddb_ignore", False):
             return False
         if model_admin.has_change_permission(request):
@@ -226,7 +228,7 @@ def _get_field_type(model, field_name, field):
                 break
         else:
             debug_log(
-                f"DDB {model.__name__}.{field_name} unsupported type {type(field).__name__}"
+                f"{model.__name__}.{field_name} unsupported type {type(field).__name__}"
             )
             res = UnknownType
 
@@ -249,9 +251,7 @@ def _get_fields_for_model(request, model, admin, admin_fields):
         field = model_fields.get(field_name)
         if field_name == _OPEN_IN_ADMIN:
             fields[_OPEN_IN_ADMIN] = OrmAdminField(model_name=model_name)
-        elif isinstance(field, (ForeignObjectRel, models.ManyToManyField)):
-            pass  # TODO 2many support
-        elif isinstance(field, models.ForeignKey):
+        elif isinstance(field, (models.ForeignKey, OneToOneRel)):
             if field.related_model in admin_fields:
                 fields[field_name] = OrmFkField(
                     model_name=model_name,
@@ -259,12 +259,14 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                     pretty_name=field_name,
                     rel_name=get_model_name(field.related_model),
                 )
+        elif isinstance(field, (ForeignObjectRel, models.ManyToManyField)):
+            pass  # TODO 2many support
         elif isinstance(field, models.FileField):
             fields[field_name] = OrmFileField(
                 model_name=model_name,
                 name=field_name,
                 pretty_name=field_name,
-                url_func=field.storage.url,
+                django_field=field,
             )
         elif isinstance(field, type(None)):
             orm_field = _get_calculated_field(
