@@ -526,9 +526,6 @@ class BoundField(BoundFieldMixin):
             query_field.priority if orm_bound_field.concrete else None,
         )
 
-    def unsorted(self):
-        return self.__class__(self.orm_bound_field, self.pivoted, None, None)
-
 
 def _orm_fields(fields):
     return [f.orm_bound_field for f in fields]
@@ -547,6 +544,8 @@ class BoundQuery:
             model_name = query.model_name
             orm_bound_field = None
             for part in parts:
+                if model_name is None:
+                    return None
                 orm_field = orm_models[model_name].fields.get(part)
                 if orm_field is None:
                     return None
