@@ -158,6 +158,35 @@ def test_get_file_link(get_product_flat):
     sortedAssert(data, [["a", None], ["b", '<a href="/media/bob.jpg">bob.jpg</a>']])
 
 
+def test_bad_storage(monkeypatch, req):
+    # break storage
+    from django.core.files.storage import FileSystemStorage, default_storage
+    from django.utils.functional import empty
+
+    def boom(*args, **kwargs):
+        assert False
+
+    monkeypatch.setattr(FileSystemStorage, "__init__", boom)
+    default_storage._wrapped = empty
+
+    # copy what the fixture does
+    orm_models = orm.get_models(req)
+
+    def get_product_flat(*args, **kwargs):
+        query = Query.from_request("tests.Product", *args)
+        bound_query = BoundQuery.bind(query, orm_models)
+        data = orm.get_results(req, bound_query, orm_models)
+        return flatten_table(bound_query.fields, data["rows"])
+
+    # some storage backends will hard fail if their underlying storage isn't
+    # setup right https://github.com/tolomea/django-data-browser/issues/11
+    producer = models.Producer.objects.create()
+    models.Product.objects.create(name="a", producer=producer)
+    models.Product.objects.create(name="b", producer=producer, image="bob.jpg")
+    data = get_product_flat("name,image", {})
+    sortedAssert(data, [["a", None], ["b", "assert False"]])
+
+
 @pytest.mark.usefixtures("products")
 def test_get_calculated_field_on_admin(get_product_flat):
     data = get_product_flat(2, "producer__address__bob", {})
@@ -369,6 +398,13 @@ def test_get_results_basic_flat(get_product_flat):
     assert data == [["a", "london"], ["b", "london"], ["c", None]]
 
 
+@pytest.mark.usefixtures("products")
+def test_get_results_one_to_one(get_product_flat):
+    # just a query
+    data = get_product_flat(1, "name+0,producer__address__producer__address__city", {})
+    assert data == [["a", "london"], ["b", "london"], ["c", None]]
+
+
 @pytest.mark.usefixtures("products")
 def test_get_results_calculated_causes_query(get_product_flat):
     # query products, fetch objects for calculated
